==> openldap-2.2.3beta.tgz: openldap-2.2.3beta/servers/slapd/back-dnssrv/init.c <==
/* init.c - initialize ldap backend */
/* $OpenLDAP: pkg/ldap/servers/slapd/back-dnssrv/init.c,v 1.17.2.2 2003/12/01 00:58:39 kurt Exp $ */
/* This work is part of OpenLDAP Software <http://www.openldap.org/>.
 *
 * Copyright 2000-2003 The OpenLDAP Foundation.
 * Portions Copyright 2000-2003 Kurt D. Zeilenga.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted only as authorized by the OpenLDAP
 * Public License.
 *
 * A copy of this license is available in the file LICENSE in the
 * top-level directory of the distribution or, alternatively, at
 * <http://www.OpenLDAP.org/license.html>.
 */
/* ACKNOWLEDGEMENTS:
 * This work was originally developed by Kurt D. Zeilenga for inclusion
 * in OpenLDAP Software.
 */

#include "portable.h"

#include <stdio.h>

#include <ac/socket.h>

#include "slap.h"
#include "external.h"

#ifdef SLAPD_DNSSRV_DYNAMIC

int init_module(int argc, char *argv[])
{
    BackendInfo bi;

    memset( &bi, '\0', sizeof(bi) );
    bi.bi_type = "dnssrv";
    bi.bi_init = dnssrv_back_initialize;

    backend_add( &bi );
    return 0;
}

#endif /* SLAPD_DNSSRV_DYNAMIC */

int
dnssrv_back_initialize(
    BackendInfo	*bi )
{
	static char *controls[] = {
		LDAP_CONTROL_MANAGEDSAIT,
 		LDAP_CONTROL_VALUESRETURNFILTER,
		NULL
	};

	bi->bi_controls = controls;

	bi->bi_open = 0;
	bi->bi_config = 0;
	bi->bi_close = 0;
	bi->bi_destroy = 0;

	bi->bi_db_init = 0;
	bi->bi_db_destroy = 0;
	bi->bi_db_config = dnssrv_back_db_config;
	bi->bi_db_open = 0;
	bi->bi_db_close = 0;

	bi->bi_chk_referrals = dnssrv_back_referrals;

	bi->bi_op_bind = dnssrv_back_bind;
	bi->bi_op_search = dnssrv_back_search;
	bi->bi_op_compare = 0 /* dnssrv_back_compare */;
	bi->bi_op_modify = 0;
	bi->bi_op_modrdn = 0;
	bi->bi_op_add = 0;
	bi->bi_op_delete = 0;
	bi->bi_op_abandon = 0;
	bi->bi_op_unbind = 0;

	bi->bi_extended = 0;

	bi->bi_connection_init = 0;
	bi->bi_connection_destroy = 0;

	return 0;
}

int
dnssrv_back_db_init(
    Backend	*be )
{
	return 0;
}

int
dnssrv_back_db_destroy(
    Backend	*be )
{
	return 0;
}

==> openldap-2.3.2beta.tgz: openldap-2.3.2beta/servers/slapd/back-dnssrv/init.c <==
/* init.c - initialize ldap backend */
/* $OpenLDAP: pkg/ldap/servers/slapd/back-dnssrv/init.c,v 1.24.2.3 2005/03/14 22:25:00 kurt Exp $ */
/* This work is part of OpenLDAP Software <http://www.openldap.org/>.
 *
 * Copyright 2000-2005 The OpenLDAP Foundation.
 * Portions Copyright 2000-2003 Kurt D. Zeilenga.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted only as authorized by the OpenLDAP
 * Public License.
 *
 * A copy of this license is available in the file LICENSE in the
 * top-level directory of the distribution or, alternatively, at
 * <http://www.OpenLDAP.org/license.html>.
 */
/* ACKNOWLEDGEMENTS:
 * This work was originally developed by Kurt D. Zeilenga for inclusion
 * in OpenLDAP Software.
 */

#include "portable.h"

#include <stdio.h>

#include <ac/socket.h>

#include "slap.h"
#include "proto-dnssrv.h"

int
dnssrv_back_initialize(
    BackendInfo	*bi )
{
	static char *controls[] = {
		LDAP_CONTROL_MANAGEDSAIT,
		NULL
	};

	bi->bi_controls = controls;

	bi->bi_open = dnssrv_back_open;
	bi->bi_config = 0;
	bi->bi_close = 0;
	bi->bi_destroy = 0;

	bi->bi_db_init = 0;
	bi->bi_db_destroy = 0;
	bi->bi_db_config = dnssrv_back_db_config;
	bi->bi_db_open = 0;
	bi->bi_db_close = 0;

	bi->bi_chk_referrals = dnssrv_back_referrals;

	bi->bi_op_bind = dnssrv_back_bind;
	bi->bi_op_search = dnssrv_back_search;
	bi->bi_op_compare = 0 /* dnssrv_back_compare */;
	bi->bi_op_modify = 0;
	bi->bi_op_modrdn = 0;
	bi->bi_op_add = 0;
	bi->bi_op_delete = 0;
	bi->bi_op_abandon = 0;
	bi->bi_op_unbind = 0;

	bi->bi_extended = 0;

	bi->bi_connection_init = 0;
	bi->bi_connection_destroy = 0;

	return 0;
}

AttributeDescription	*ad_dc;
AttributeDescription	*ad_associatedDomain;

int
dnssrv_back_open(
    BackendInfo *bi )
{
	const char *text;

	(void)slap_str2ad( "dc", &ad_dc, &text );
	(void)slap_str2ad( "associatedDomain", &ad_associatedDomain, &text );

	return 0;
}

int
dnssrv_back_db_init(
    Backend	*be )
{
	return 0;
}

int
dnssrv_back_db_destroy(
    Backend	*be )
{
	return 0;
}

#if SLAPD_DNSSRV == SLAPD_MOD_DYNAMIC

/* conditionally define the init_module() function */
SLAP_BACKEND_INIT_MODULE( dnssrv )

#endif /* SLAPD_DNSSRV == SLAPD_MOD_DYNAMIC */
